# Outcome Journal

> Track significant decisions and follow up on them.

## Active Decisions

| Date | Decision | Follow-up Due | Status |
|------|----------|--------------|--------|
| — | — | — | — |

## Completed Follow-ups

> Log completed follow-ups here
